@@ -65,6 +65,12 @@ class CourseSectionMinForm(forms.ModelForm):
         fields = ['section', 'order_by', 'mins']
 
 
+# 课件问题
+class CourseSectionQuestionSearchForm(forms.Form):
+    question_has_correct_choices = ((-1, '全部'), (1, "有"), (0, "无"))
+    question_has_correct = forms.ChoiceField(choices=question_has_correct_choices, label='正确答案', required=False)
+    question_name = forms.CharField(label='问题', required=False)
+
 class VideoForm(forms.ModelForm):
     class Meta:
         model = Video
