@@ -227,6 +227,13 @@ class SectionQuestion(models.Model):
     def get_correct_options(self):
         return SectionQuestionOption.objects.filter(question=self, is_correct=True)
 
+    # 获取【无】正确答案的问题
+    @classmethod
+    def get_has_correct_questions(cls, has_correct=False):
+        if has_correct:
+            return cls.objects.filter(options__is_correct=True)
+        else:
+            return cls.objects.exclude(options__is_correct=True)
 
 
 class SectionQuestionOption(models.Model):
