@@ -30,7 +30,7 @@ urlpatterns = [
     # ===== 课程课件======
     url(r'^course/section/add/(?P<course_id>[0-9]+)/$', views.CourseSectionMidCreate.as_view(),
         name='course_section_mid_add'),
-    # 修改课程课件的排序
+    # 修改课程课件mid的字段
     url(r'^course/section/update/(?P<csm_id>\d+)$', views.update_coursesectionmid, name='update_coursesectionmid'),
     # 图片上传
     url(r'^upload_image$', views.upload_image, name='upload_image'),
@@ -56,6 +56,7 @@ urlpatterns = [
     url(r'^course/section/option/add/(?P<question_id>[0-9]+)/$', views.SectionQuestionOptionCreate.as_view(), name='question_option_add'),
     url(r'^course/section/option/delete/(?P<option_id>[0-9]+)/$', views.SectionQuestionOptionDelete.as_view(), name='question_option_delete'),
     url(r'^course/section/question/answer/(?P<user_section_id>[0-9]+)/$', views.SectionQuestionAnswer.as_view(), name='question_answer'),
+    url(r'^user/question/answer/record/(?P<user_section_id>[0-9]+)/$', views.UserQuestionAnswerRecordList.as_view(), name='user_question_answer'),
 
     # ===== 视频 ======
     url(r'^video/list/$', views.VideoList.as_view(), name='video_list'),
@@ -71,8 +72,8 @@ urlpatterns = [
     # url(r'^vodio/play/$', views.play_video, name='play_video'),
 
     # ===== 录播 ======
-    url(r'^live/list/$', views.LiveList.as_view(), name='live_list'),
-    url(r'^live/list/(?P<user_id>[0-9]+)/$', views.manage_user_live_list, name='user_live_list'),
+    url(r'^live/list/(?P<user_id>[0-9]+)/$', views.LiveList.as_view(), name='live_list'),
+    # url(r'^live/list/(?P<user_id>[0-9]+)/$', views.UserLiveList.as_view(), name='user_live_list'),
     # 查看录播视频页
     url(r'^live/video/(?P<live_video_id>(.)+)/$', views.live_video_detail, name='live_video_detail'),
     # 用户查看录播视频
