@@ -19,7 +19,8 @@ from .models import Course, Section, CourseSectionMid, Video, UserLive, UserCour
     Preference, UserSectionNote, SectionVideo, SectionQuestion, SectionQuestionOption, UserQuestionAnswerRecord
 from .forms import CourseForm, SectionForm, CourseSectionForm, CourseSectionOrderForm, VideoForm, UploadImageForm, \
     UserCourseForm, UserAssignmentForm, UserAssignmentImageForm, SectionVideoForm, PreferenceForm, \
-    section_attach_form, UserSectionNoteForm, SectionVideoOrderForm, LivePlayLogsForm, UserLiveCommentForm
+    section_attach_form, UserSectionNoteForm, SectionVideoOrderForm, LivePlayLogsForm, UserLiveCommentForm, \
+    CourseSectionQuestionSearchForm
 from .utils import JSONResponse, page_it
 from .cc import create_video_info, get_video_str, get_play_logs
 from django.http import JsonResponse
@@ -46,13 +47,14 @@ class CourseRedirectView(RedirectView):
     # else:
     #     pattern_name = 'bee_django_course:section_list'
     query_string = True
+
     def get_redirect_url(self, *args, **kwargs):
         if self.request.user.has_perm('bee_django_course.view_all_courses'):
             # 跳转 CourseList
             self.pattern_name = 'bee_django_course:course_list'
         elif self.request.user.has_perm('bee_django_course.view_teach_usercoursessection'):
             # self.pattern_name = 'bee_django_course:live_list'
-            self.url = reverse('bee_django_course:live_list',kwargs={"user_id":0})
+            self.url = reverse('bee_django_course:live_list', kwargs={"user_id": 0})
         else:
             self.url = '/'
         return super(CourseRedirectView, self).get_redirect_url(*args, **kwargs)
@@ -71,7 +73,7 @@ class CourseList(ListView):
         if request.user.has_perm('bee_django_course.view_all_courses'):
             return super(CourseList, self).get(request, *args, **kwargs)
         elif request.user.has_perm('bee_django_course.view_teach_usercoursessection'):
-            return redirect(reverse('bee_django_course:live_list',kwargs={"user_id":0}))
+            return redirect(reverse('bee_django_course:live_list', kwargs={"user_id": 0}))
 
 
 @method_decorator(cls_decorator(cls_name='CourseDetail'), name='dispatch')
@@ -421,15 +423,13 @@ class LiveList(ListView):
     paginate_by = 20
     queryset = None
 
-
     def get_user(self):
         user_id = self.kwargs["user_id"]
-        if not user_id in [None,'0']:
+        if not user_id in [None, '0']:
             user = User.objects.get(id=user_id)
             return user
         return None
 
-
     def get_queryset(self):
         if self.request.user.has_perm("bee_django_course.view_all_userlives"):
             self.queryset = UserLive.objects.filter(status=1)
@@ -440,7 +440,7 @@ class LiveList(ListView):
             return []
         user = self.get_user()
         if user:
-            self.queryset = self.queryset.filter(user = user)
+            self.queryset = self.queryset.filter(user=user)
         return self.queryset
 
     def get_context_data(self, **kwargs):
@@ -451,8 +451,6 @@ class LiveList(ListView):
         return context
 
 
-
-
 # # 查看单个学生的所有录播
 # @method_decorator(cls_decorator(cls_name='UserLiveList'), name='dispatch')
 # class UserLiveList(ListView):
@@ -681,6 +679,7 @@ class UserCourseSectionDetail(DetailView):
         context["open_notes"] = open_notes
         context["my_notes"] = my_notes
         context["note_form"] = note_form
+        context["questions"] = section.get_questions()
         return context
 
     def post(self, request, *args, **kwargs):
@@ -1415,7 +1414,7 @@ class UserQuestionAnswerRecordList(ListView):
 
     def get_ucs(self):
         user_section_id = self.kwargs["user_section_id"]
-        print(user_section_id)
+        # print(user_section_id)
         if not user_section_id in ["0", None]:
             ucs = UserCourseSection.objects.get(id=user_section_id)
             return ucs
@@ -1428,16 +1427,32 @@ class UserQuestionAnswerRecordList(ListView):
             return ucs.user_course.user
         return None
 
-    def get_queryset(self):
+    def search(self):
+
         ucs = self.get_ucs()
         if ucs:
-            question_list = ucs.section.get_questions()
-            return question_list
+            self.queryset = ucs.section.get_questions()
+        # 只有显示全部问题，即没有ucs时，才可搜索
         else:
-            return SectionQuestion.objects.all()
+            question_has_correct = self.request.GET.get("question_has_correct")
+            question_name = self.request.GET.get("question_name")
+
+            if question_has_correct in ["-1", None]:
+                self.queryset = SectionQuestion.objects.all()
+            else:
+                if question_has_correct in ["1"]:
+                    self.queryset = SectionQuestion.get_has_correct_questions(has_correct=True)
+                elif question_has_correct in ["0"]:
+                    self.queryset = SectionQuestion.get_has_correct_questions(has_correct=False)
+            if question_name:
+                self.queryset = self.queryset.filter(question__contains=question_name)
+
+        return self.queryset
 
     def get_context_data(self, **kwargs):
         context = super(UserQuestionAnswerRecordList, self).get_context_data(**kwargs)
+        question_has_correct = self.request.GET.get("question_has_correct")
+        question_name = self.request.GET.get("question_name")
         ucs = self.get_ucs()
         if ucs:
             user = ucs.user_course.user
@@ -1445,8 +1460,20 @@ class UserQuestionAnswerRecordList(ListView):
             user = None
         context["ucs"] = ucs
         context["user"] = user
+        context["user_section_id"] = self.kwargs["user_section_id"]
+        context["search_form"] = CourseSectionQuestionSearchForm(
+            {"question_has_correct": question_has_correct, "question_name": question_name})
         return context
 
+    def get(self, request, *args, **kwargs):
+        self.queryset = self.search()
+        if request.GET.get("export"):
+            pass
+            # rows = ([(i + 1).__str__()] + self.get_csv_info(fee) for i, fee in enumerate(self.queryset))
+            # return export_csv('缴费信息'.encode('utf-8'), self.get_csv_headers(), rows)
+        else:
+            return super(UserQuestionAnswerRecordList, self).get(request, *args, **kwargs)
+
 
 # 用户答题正确，更新ucs状态，返回用户学习课程的列表
 def ucs_question_passed(request, ucs_id):
